/**
 * Contentful Delivery API Client. Contains methods which allow access to the
 * different kinds of entities present in Contentful (Entries, Assets, etc).
 */
import { AxiosInstance } from 'contentful-sdk-core';
import { GetGlobalOptions } from './create-global-options';
import { Asset, AssetCollection, AssetFields, AssetKey, AssetQueries, ContentType, ContentTypeCollection, EntriesQueries, LocaleCollection, LocaleCode, Space, SyncCollection, Tag, TagCollection, Entry, EntryCollection } from './types';
import { EntryQueries } from './types/query/query';
import { FieldsType } from './types/query/util';
import { ChainOptions } from './utils/client-helpers';
export type ClientWithLinkResolutionAndWithUnresolvableLinks = BaseClient & BaseClientWithAssets & {
    withAllLocales: ClientWithAllLocalesAndWithLinkResolutionAndWithUnresolvableLinks;
    withoutLinkResolution: ClientWithoutLinkResolution;
    withoutUnresolvableLinks: ClientWithLinkResolutionAndWithoutUnresolvableLinks;
    getEntry<Fields extends FieldsType>(id: string, query?: EntryQueries): Promise<Entry<Fields, undefined>>;
    getEntries<Fields extends FieldsType>(query?: EntriesQueries<Fields>): Promise<EntryCollection<Fields, undefined>>;
    parseEntries<Fields extends FieldsType = FieldsType>(data: EntryCollection<Fields, 'WITHOUT_LINK_RESOLUTION'>): EntryCollection<Fields, undefined>;
};
export type ClientWithoutLinkResolution = BaseClient & BaseClientWithAssets & {
    withAllLocales: ClientWithAllLocalesAndWithoutLinkResolution;
    getEntry<Fields extends FieldsType>(id: string, query?: EntryQueries): Promise<Entry<Fields, 'WITHOUT_LINK_RESOLUTION'>>;
    getEntries<Fields extends FieldsType>(query?: EntriesQueries<Fields>): Promise<EntryCollection<Fields, 'WITHOUT_LINK_RESOLUTION'>>;
    parseEntries<Fields extends FieldsType = FieldsType>(data: EntryCollection<Fields, 'WITHOUT_LINK_RESOLUTION'>): EntryCollection<Fields, 'WITHOUT_LINK_RESOLUTION'>;
};
export type ClientWithAllLocalesAndWithLinkResolutionAndWithUnresolvableLinks = BaseClient & BaseClientWithAssetsWithAllLocales & {
    withoutLinkResolution: ClientWithAllLocalesAndWithoutLinkResolution;
    withoutUnresolvableLinks: ClientWithAllLocalesAndWithLinkResolutionAndWithoutUnresolvableLinks;
    getEntry<Fields extends FieldsType = FieldsType, Locales extends LocaleCode = LocaleCode>(id: string, query?: EntryQueries & {
        locale?: never;
    }): Promise<Entry<Fields, 'WITH_ALL_LOCALES', Locales>>;
    getEntries<Fields extends FieldsType, Locales extends LocaleCode = LocaleCode>(query?: EntriesQueries<Fields> & {
        locale?: never;
    }): Promise<EntryCollection<Fields, 'WITH_ALL_LOCALES', Locales>>;
    parseEntries<Fields extends FieldsType = FieldsType, Locales extends LocaleCode = LocaleCode>(data: EntryCollection<Fields, 'WITHOUT_LINK_RESOLUTION' | 'WITH_ALL_LOCALES', Locales>): EntryCollection<Fields, 'WITH_ALL_LOCALES', Locales>;
};
export type ClientWithAllLocalesAndWithoutLinkResolution = BaseClient & BaseClientWithAssetsWithAllLocales & {
    getEntry<Fields extends FieldsType, Locales extends LocaleCode = LocaleCode>(id: string, query?: EntryQueries & {
        locale?: never;
    }): Promise<Entry<Fields, 'WITH_ALL_LOCALES' | 'WITHOUT_LINK_RESOLUTION', Locales>>;
    getEntries<Fields extends FieldsType, Locales extends LocaleCode = LocaleCode>(query?: EntriesQueries<Fields> & {
        locale?: never;
    }): Promise<EntryCollection<Fields, 'WITH_ALL_LOCALES' | 'WITHOUT_LINK_RESOLUTION', Locales>>;
    parseEntries<Fields extends FieldsType = FieldsType, Locales extends LocaleCode = LocaleCode>(data: EntryCollection<Fields, 'WITHOUT_LINK_RESOLUTION' | 'WITH_ALL_LOCALES', Locales>): EntryCollection<Fields, 'WITH_ALL_LOCALES' | 'WITHOUT_LINK_RESOLUTION', Locales>;
};
export type ClientWithLinkResolutionAndWithoutUnresolvableLinks = BaseClient & BaseClientWithAssets & {
    withAllLocales: ClientWithAllLocalesAndWithLinkResolutionAndWithUnresolvableLinks;
    getEntry<Fields extends FieldsType>(id: string, query?: EntryQueries): Promise<Entry<Fields, 'WITHOUT_UNRESOLVABLE_LINKS'>>;
    getEntries<Fields extends FieldsType>(query?: EntriesQueries<Fields>): Promise<EntryCollection<Fields, 'WITHOUT_UNRESOLVABLE_LINKS'>>;
    parseEntries<Fields extends FieldsType = FieldsType>(data: EntryCollection<Fields, 'WITHOUT_LINK_RESOLUTION'>): EntryCollection<Fields, 'WITHOUT_UNRESOLVABLE_LINKS'>;
};
export type ClientWithAllLocalesAndWithLinkResolutionAndWithoutUnresolvableLinks = BaseClient & BaseClientWithAssetsWithAllLocales & {
    getEntry<Fields extends FieldsType, Locales extends LocaleCode = any>(id: string, query?: EntryQueries & {
        locale?: never;
    }): Promise<Entry<Fields, 'WITH_ALL_LOCALES' | 'WITHOUT_UNRESOLVABLE_LINKS', Locales>>;
    getEntries<Fields extends FieldsType, Locales extends LocaleCode = any>(query?: EntriesQueries<Fields> & {
        locale?: never;
    }): Promise<EntryCollection<Fields, 'WITH_ALL_LOCALES' | 'WITHOUT_UNRESOLVABLE_LINKS', Locales>>;
    parseEntries<Fields extends FieldsType = FieldsType, Locales extends LocaleCode = LocaleCode>(data: EntryCollection<Fields, 'WITHOUT_LINK_RESOLUTION' | 'WITH_ALL_LOCALES', Locales>): EntryCollection<Fields, 'WITH_ALL_LOCALES' | 'WITHOUT_UNRESOLVABLE_LINKS', Locales>;
};
export type DefaultClient = ClientWithLinkResolutionAndWithUnresolvableLinks;
interface BaseClient {
    version: string;
    /**
     * Gets a Content Type
     * @category API
     * @example
     * ```javascript
     * const contentful = require('contentful')
     *
     * const client = contentful.createClient({
     *   space: '<space_id>',
     *   accessToken: '<content_delivery_api_key>'
     * })
     *
     * const contentType = await client.getContentType('<content_type_id>')
     * console.log(contentType)
     * ```
     */
    getContentType(id: string): Promise<ContentType>;
    /**
     * Gets a collection of Content Types
     * @category API
     * @example
     * ```javascript
     * const contentful = require('contentful')
     *
     * const client = contentful.createClient({
     *   space: '<space_id>',
     *   accessToken: '<content_delivery_api_key>'
     * })
     *
     * const response = await client.getContentTypes()
     * console.log(response.items)
     * ```
     */
    getContentTypes(query?: {
        query?: string;
    }): Promise<ContentTypeCollection>;
    /**
     * Gets the Space which the client is currently configured to use
     * @category API
     * @example
     * ```javascript
     * const contentful = require('contentful')
     *
     * const client = contentful.createClient({
     *   space: '<space_id>',
     *   accessToken: '<content_delivery_api_key>'
     * })
     * // returns the space object with the above <space-id>
     * const space = await client.getSpace()
     * console.log(space)
     * ```
     */
    getSpace(): Promise<Space>;
    /**
     * Gets a collection of Locales
     * @category API
     * @example
     * ```javascript
     * const contentful = require('contentful')
     *
     * const client = contentful.createClient({
     *   space: '<space_id>',
     *   accessToken: '<content_delivery_api_key>'
     * })
     *
     * const response = await client.getLocales()
     * console.log(response.items)
     * ```
     */
    getLocales(): Promise<LocaleCollection>;
    /**
     * Synchronizes either all the content or only new content since last sync
     * See <a href="https://www.contentful.com/developers/docs/concepts/sync/">Synchronization</a> for more information.
     * <strong> Important note: </strong> The the sync api endpoint does not support include or link resolution.
     * However contentful.js is doing link resolution client side if you only make an initial sync.
     * For the delta sync (using nextSyncToken) it is not possible since the sdk wont have access to all the data to make such an operation.
     * @category API
     * @example
     * ```javascript
     * const contentful = require('contentful')
     *
     * const client = contentful.createClient({
     *   space: '<space_id>',
     *   accessToken: '<content_delivery_api_key>'
     * })
     *
     * const response = await client.sync({
     *   initial: true
     * })
     * console.log({
     *   entries: response.entries,
     *   assets: response.assets,
     *   nextSyncToken: response.nextSyncToken
     * })
     * ```
     */
    sync(query: any): Promise<SyncCollection>;
    /**
     * Gets a Tag
     * @category API
     * @example
     * const contentful = require('contentful')
     *
     * const client = contentful.createClient({
     *   space: '<space_id>',
     *   accessToken: '<content_delivery_api_key>'
     * })
     *
     * const tag = await client.getTag('<asset_id>')
     * console.log(tag)
     */
    getTag(id: string): Promise<Tag>;
    /**
     * Gets a collection of Tags
     * @category API
     * @example
     * const contentful = require('contentful')
     *
     * const client = contentful.createClient({
     *   space: '<space_id>',
     *   accessToken: '<content_delivery_api_key>'
     * })
     *
     * const response = await client.getTags()
     * console.log(response.items)
     */
    getTags(query?: any): Promise<TagCollection>;
    /**
     * Creates an asset key for signing asset URLs (Embargoed Assets)
     * @category API
     * @example
     * const contentful = require('contentful')
     *
     * const client = contentful.createClient({
     *   space: '<space_id>',
     *   accessToken: '<content_delivery_api_key>'
     * })
     *
     * const assetKey = await client.getAssetKey(<UNIX timestamp>)
     * console.log(assetKey)
     */
    createAssetKey(expiresAt: number): Promise<AssetKey>;
}
interface BaseClientWithAssets extends BaseClient {
    /**
     * Gets an Asset
     * @category API
     * @example
     * ```javascript
     * const contentful = require('contentful')
     *
     * const client = contentful.createClient({
     *   space: '<space_id>',
     *   accessToken: '<content_delivery_api_key>'
     * })
     *
     * const asset = await client.getAsset('<asset_id>')
     * console.log(asset)
     * ```
     */
    getAsset(id: string, query?: {
        locale?: string;
    }): Promise<Asset<undefined>>;
    /**
     * Gets a collection of Assets
     * @category API
     * @example
     * ```javascript
     * const contentful = require('contentful')
     *
     * const client = contentful.createClient({
     *   space: '<space_id>',
     *   accessToken: '<content_delivery_api_key>'
     * })
     *
     * const response = await client.getAssets()
     * console.log(response.items)
     * ```
     */
    getAssets(query?: AssetQueries<AssetFields>): Promise<AssetCollection<undefined>>;
}
interface BaseClientWithAssetsWithAllLocales extends BaseClient {
    /**
     * Gets an Asset
     * @category API
     * @example
     * ```javascript
     * const contentful = require('contentful')
     *
     * const client = contentful.createClient({
     *   space: '<space_id>',
     *   accessToken: '<content_delivery_api_key>'
     * })
     *
     * const asset = await client.getAsset('<asset_id>')
     * console.log(asset)
     * ```
     */
    getAsset<Locale extends LocaleCode>(id: string, query?: {
        locale?: string;
    }): Promise<Asset<'WITH_ALL_LOCALES', Locale>>;
    /**
     * Gets a collection of Assets
     * @category API
     * @example
     * ```javascript
     * const contentful = require('contentful')
     *
     * const client = contentful.createClient({
     *   space: '<space_id>',
     *   accessToken: '<content_delivery_api_key>'
     * })
     *
     * const response = await client.getAssets()
     * console.log(response.items)
     * ```
     */
    getAssets<Locales extends LocaleCode>(query?: AssetQueries<AssetFields>): Promise<AssetCollection<'WITH_ALL_LOCALES', Locales>>;
}
export interface CreateContentfulApiParams {
    http: AxiosInstance;
    getGlobalOptions: GetGlobalOptions;
}
export type ContentfulClientApi = DefaultClient;
export default function createContentfulApi<OptionType extends ChainOptions>({ http, getGlobalOptions }: CreateContentfulApiParams, options?: OptionType): DefaultClient;
export {};
